Account class

Accounts are what businesses use to track transactions. Accounts can track money coming in (income or revenue) and going out (expenses). They can also track the value of things (assets), like vehicles and equipment. There are five basic account types: asset, liability, income, expense, and equity. Accounts are part of the chart of accounts, the unique list of accounts each business puts together to do their accounting. Accountants often call accounts "ledgers". Learn more about accounts and the chart of accounts. The account object is what you'll use to do actions with the end-users accounts. Note: If you need to delete an account, set the Active attribute to false in an object update request. This makes it inactive. The account itself isn't permanently deleted, but is hidden for display purposes. References to inactive objects remain intact.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Account({String? id, String? name, String? accountAlias, String? accountSubType, String? accountType, String? acctNum, bool? active, String? classification, DateTime? createTime, CurrencyRefType? currencyRef, double? currentBalance, double? currentBalanceWithSubAccounts, String? description, String? fullyQualifiedName, DateTime? lastUpdatedTime, ModificationMetaData? metaData, ReferenceType? parentRef, bool? subAccount, String? syncToken, ReferenceType? taxCodeRef, String? txnLocationType})
Account.fromJson(Map<String, dynamic> json)
factory

Properties

accountAlias → String?
final
accountSubType → String?
final
accountType → String?
final
acctNum → String?
final
active → bool?
final
classification → String?
final
createTime → DateTime?
final
currencyRef → CurrencyRefType?
final
currentBalance ↔ double?
getter/setter pair
currentBalanceWithSubAccounts → double?
final
description → String?
final
fullyQualifiedName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
lastUpdatedTime → DateTime?
final
metaData → ModificationMetaData?
final
name → String?
final
parentRef → ReferenceType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subAccount → bool?
final
syncToken → String?
final
taxCodeRef → ReferenceType?
final
txnLocationType → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited