AccountBasedExpense class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

AccountBasedExpense({double? taxInclusiveAmt, MarkupInfo? markupInfo, ReferenceType? customerRef, ReferenceType? classRef, BillableStatusEnum? billableStatus, ReferenceType? taxCodeRef, required ReferenceType accountRef, double? taxAmount})
AccountBasedExpense.fromJson(Map<String, dynamic> json)
factory

Properties

accountRef → ReferenceType
final
billableStatus → BillableStatusEnum?
final
classRef → ReferenceType?
final
customerRef → ReferenceType?
final
hashCode → int
The hash code for this object.
no setterinherited
markupInfo → MarkupInfo?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxAmount → double?
final
taxCodeRef → ReferenceType?
final
taxInclusiveAmt → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited