AccountingInfoPrefs class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

AccountingInfoPrefs({String? bookCloseDate, bool? classTrackingPerTxn, bool? classTrackingPerTxnLine, String? customerTerminology, String? departmentTerminology, String? firstMonthOfFiscalYear, String? taxForm, String? taxYearMonth, bool? trackDepartments, bool? useAccountNumbers})
AccountingInfoPrefs.fromJson(Map<String, dynamic> json)
factory

Properties

bookCloseDate → String?
final
classTrackingPerTxn → bool?
final
classTrackingPerTxnLine → bool?
final
customerTerminology → String?
final
departmentTerminology → String?
final
firstMonthOfFiscalYear → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxForm → String?
final
taxYearMonth → String?
final
trackDepartments → bool?
final
useAccountNumbers → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited