BankAccount class

Quickbooks - Payments Store bank accounts for processing future payments. Applicable for US only

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

BankAccount({String? id, String? name, String? country, BankAccountTypeEnum? accountType, String? accountNumber, String? bankCode, String? created, bool? isDefault, String? entityId, String? entityType, String? inputType, String? phone, String? routingNumber, String? updated})
BankAccount.fromJson(Map<String, dynamic> json)
factory

Properties

accountNumber → String?
final
accountType → BankAccountTypeEnum?
final
bankCode → String?
final
country → String?
final
created → String?
final
entityId → String?
final
entityType → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
inputType → String?
final
isDefault → bool?
final
name → String?
final
phone → String?
final
routingNumber → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updated → String?
final

Methods

copyWith({String? id, String? name, String? accountNumber, String? phone, BankAccountTypeEnum? accountType, String? routingNumber, String? updated, bool? isDefault, String? country, String? inputType, String? entityType, String? created, String? bankCode, String? entityId}) → BankAccount
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited