Bill class

A Bill object is an AP transaction representing a request-for-payment from a third party for goods/services rendered, received, or both.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Bill({String? txnDate, List<LinkedTxn>? linkedTxn, ReferenceType? aPAccountRef, CurrencyRefType? currencyRef, String? syncToken, String? id, ModificationMetaData? metaData, double? balance, ReferenceType? departmentRef, String? docNumber, String? dueDate, double? exchangeRate, GlobalTaxCalculationEnum? globalTaxCalculation, double? homeBalance, bool? includeInAnnualTPAR, List<Line>? line, String? privateNote, ReferenceType? recurDataRef, ReferenceType? salesTermRef, double? totalAmt, String? transactionLocationType, TxnTaxDetail? txnTaxDetail, ReferenceType? vendorRef})
Bill.fromJson(Map<String, dynamic> json)
factory

Properties

aPAccountRef → ReferenceType?
final
balance → double?
final
currencyRef → CurrencyRefType?
final
departmentRef → ReferenceType?
final
docNumber → String?
final
dueDate → String?
final
exchangeRate → double?
final
globalTaxCalculation → GlobalTaxCalculationEnum?
final
hashCode → int
The hash code for this object.
no setterinherited
homeBalance → double?
final
id → String?
final
includeInAnnualTPAR → bool?
final
line → List<Line>?
final
linkedTxn → List<LinkedTxn>?
final
metaData → ModificationMetaData?
final
privateNote → String?
final
recurDataRef → ReferenceType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salesTermRef → ReferenceType?
final
syncToken → String?
final
totalAmt → double?
final
transactionLocationType → String?
final
txnDate → String?
final
txnTaxDetail → TxnTaxDetail?
final
vendorRef → ReferenceType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited