Card class

Store credit cards and debit cards for processing future payments. Note that storing cards for swiped transactions is not currently supported by the payments API. Applicable for US and Canada only

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Card({String? updated, String? entityType, String? entityId, String? created, String? name, String? id, Address? address, CardTypeEnum? cardType, String? commercialCardCode, String? cvc, String? expMonth, String? expYear, bool? isBusiness, bool? isDefault, bool? isLevel3Eligible, String? number, ZeroDollarVerification? zeroDollarVerification})
Card.fromJson(Map<String, dynamic> json)
factory

Properties

address → Address?
final
cardType → CardTypeEnum?
final
commercialCardCode → String?
final
created → String?
final
cvc → String?
final
entityId → String?
final
entityType → String?
final
expMonth → String?
final
expYear → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
isBusiness → bool?
final
isDefault → bool?
final
isLevel3Eligible → bool?
final
name → String?
final
number → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updated → String?
final
zeroDollarVerification → ZeroDollarVerification?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited