Charge class

Send and receive payments using credit cards and debit cards. Applicable for US and Canada only

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Charge({ChargeStatusEnum? status, String? id, String? created, String? currency, String? amount, String? authCode, String? description, String? avsStreet, String? avsZip, bool? capture, CaptureDetail? captureDetail, Card? card, String? cardSecurityCodeMatch, PaymentContext? context, String? token})
Charge.fromJson(Map<String, dynamic> json)
factory

Properties

amount → String?
final
authCode → String?
final
avsStreet → String?
final
avsZip → String?
final
capture → bool?
final
captureDetail → CaptureDetail?
final
card → Card?
final
cardSecurityCodeMatch → String?
final
context → PaymentContext?
final
created → String?
final
currency → String?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ChargeStatusEnum?
final
token → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited