CompanyInfo class

The CompanyInfo object contains basic company information. In QuickBooks, company info and preferences are displayed in the same place under preferences, so it may be confusing to figure out from user interface which fields may belong to this object. But in general, properties such as company addresses or name are considered company information. Some attributes may exist in both CompanyInfo and Preferences objects.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CompanyInfo({String? id, String? syncToken, PhysicalAddress? companyAddr, String? companyName, String? companyStartDate, String? country, PhysicalAddress? customerCommunicationAddr, EmailAddress? email, String? fiscalYearStartMonth, PhysicalAddress? legalAddr, String? legalName, ModificationMetaData? metaData, List<NameValue>? pairs, TelephoneNumber? primaryPhone, String? supportedLanguages, WebSiteAddress? webAddr})
CompanyInfo.fromJson(Map<String, dynamic> json)
factory

Properties

companyAddr → PhysicalAddress?
final
companyName → String?
final
companyStartDate → String?
final
country → String?
final
customerCommunicationAddr → PhysicalAddress?
final
email → EmailAddress?
final
fiscalYearStartMonth → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
legalAddr → PhysicalAddress?
final
legalName → String?
final
metaData → ModificationMetaData?
final
pairs → List<NameValue>?
final
primaryPhone → TelephoneNumber?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedLanguages → String?
final
syncToken → String?
final
webAddr → WebSiteAddress?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited