CreditChargeInfo class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CreditChargeInfo({String? type, double? amount, String? postalCode, String? billAddrStreet, int? ccExpiryMonth, int? ccExpiryYear, String? nameOnAcct, bool? processPayment})
CreditChargeInfo.fromJson(Map<String, dynamic> json)
factory

Properties

amount → double?
final
billAddrStreet → String?
final
ccExpiryMonth → int?
final
ccExpiryYear → int?
final
hashCode → int
The hash code for this object.
no setterinherited
nameOnAcct → String?
final
postalCode → String?
final
processPayment → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited