CreditChargeResponse class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CreditChargeResponse({String? authCode, String? cCTransId, CCPaymentStatusEnum? status, DateTime? txnAuthorizationTime})
CreditChargeResponse.fromJson(Map<String, dynamic> json)
factory

Properties

authCode → String?
final
cCTransId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → CCPaymentStatusEnum?
final
txnAuthorizationTime → DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited