CustomField class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

CustomField({String? name, required String? definitionId, String? stringValue, CustomFieldTypeEnum? type, bool? booleanValue})
CustomField.fromJson(Map<String, dynamic> json)
factory

Properties

booleanValue → bool?
final
definitionId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String?
final
type → CustomFieldTypeEnum?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited