Customer class

A customer is a consumer of the service or product that your business offers. An individual customer can have an underlying nested structure, with a parent customer (the top-level object) having zero or more sub-customers and jobs associated with it.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Customer({String? id, WebSiteAddress? webAddr, TelephoneNumber? primaryPhone, String? companyName, String? syncToken, ReferenceType? salesTermRef, double? balance, ModificationMetaData? metaData, CurrencyRefType? currencyRef, String? fullyQualifiedName, ReferenceType? parentRef, bool? active, TelephoneNumber? alternatePhone, ReferenceType? aRAccountRef, double? balanceWithJobs, PhysicalAddress? billAddr, bool? billWithParent, String? businessNumber, String? customerTypeRef, ReferenceType? defaultTaxCodeRef, String? displayName, String? familyName, TelephoneNumber? fax, String? givenName, String? gSTIN, String? gSTRegistrationType, bool? isProject, bool? job, int? level, String? middleName, TelephoneNumber? mobile, String? notes, String? openBalanceDate, ReferenceType? paymentMethodRef, String? preferredDeliveryMethod, EmailAddress? primaryEmailAddr, String? primaryTaxIdentifier, String? printOnCheckName, String? resaleNum, String? secondaryTaxIdentifier, PhysicalAddress? shipAddr, String? source, String? suffix, bool? taxable, int? taxExemptionReasonId, String? title})
Customer.fromJson(Map<String, dynamic> json)
factory

Properties

active → bool?
final
alternatePhone → TelephoneNumber?
final
aRAccountRef → ReferenceType?
final
balance → double?
final
balanceWithJobs → double?
final
billAddr → PhysicalAddress?
final
billWithParent → bool?
final
businessNumber → String?
final
companyName → String?
final
currencyRef → CurrencyRefType?
final
customerTypeRef → String?
final
defaultTaxCodeRef → ReferenceType?
final
displayName → String?
final
familyName → String?
final
fax → TelephoneNumber?
final
fullyQualifiedName → String?
final
givenName → String?
final
gSTIN → String?
final
gSTRegistrationType → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
isProject → bool?
final
job → bool?
final
level → int?
final
metaData → ModificationMetaData?
final
middleName → String?
final
mobile → TelephoneNumber?
final
notes → String?
final
openBalanceDate → String?
final
parentRef → ReferenceType?
final
paymentMethodRef → ReferenceType?
final
preferredDeliveryMethod → String?
final
primaryEmailAddr → EmailAddress?
final
primaryPhone → TelephoneNumber?
final
primaryTaxIdentifier → String?
final
printOnCheckName → String?
final
resaleNum → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salesTermRef → ReferenceType?
final
secondaryTaxIdentifier → String?
final
shipAddr → PhysicalAddress?
final
source → String?
final
suffix → String?
final
syncToken → String?
final
taxable → bool?
final
taxExemptionReasonId → int?
final
title → String?
final
webAddr → WebSiteAddress?
final

Methods

copyWith({String? id, String? syncToken, String? displayName, String? title, String? givenName, String? middleName, String? suffix, String? familyName, EmailAddress? primaryEmailAddr, String? resaleNum, String? secondaryTaxIdentifier, ReferenceType? aRAccountRef, ReferenceType? defaultTaxCodeRef, String? preferredDeliveryMethod, String? gSTIN, ReferenceType? salesTermRef, String? customerTypeRef, TelephoneNumber? fax, String? businessNumber, bool? billWithParent, CurrencyRefType? currencyRef, TelephoneNumber? mobile, bool? job, double? balanceWithJobs, TelephoneNumber? primaryPhone, String? openBalanceDate, bool? taxable, TelephoneNumber? alternatePhone, ModificationMetaData? metaData, ReferenceType? parentRef, String? notes, WebSiteAddress? webAddr, bool? active, String? companyName, double? balance, PhysicalAddress? shipAddr, ReferenceType? paymentMethodRef, bool? isProject, String? source, String? primaryTaxIdentifier, String? gSTRegistrationType, String? printOnCheckName, PhysicalAddress? billAddr, String? fullyQualifiedName, int? level, int? taxExemptionReasonId}) → Customer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited