DeviceInfo class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

DeviceInfo({String? id, String? type, bool? encrypted, String? ipAddress, String? latitude, String? longitude, String? macAddress, String? phoneNumber})
DeviceInfo.fromJson(Map<String, dynamic> json)
factory

Properties

encrypted → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
ipAddress → String?
final
latitude → String?
final
longitude → String?
final
macAddress → String?
final
phoneNumber → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited