DiscountLine class

Implemented types
Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

DiscountLine({double? amount, int? lineNum, String? description, String? id, String? detailType, DiscountLineDetail? discountLineDetail})
DiscountLine.fromJson(Map<String, dynamic> json)
factory

Properties

amount → double?
final
description → String?
final
detailType → String?
final
discountLineDetail → DiscountLineDetail?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
lineNum → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited