DiscountLineDetail class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

DiscountLineDetail({ReferenceType? taxCodeRef, ReferenceType? classRef, bool? percentBased, ReferenceType? discountAccountRef, double? discountPercent})
DiscountLineDetail.fromJson(Map<String, dynamic> json)
factory

Properties

classRef → ReferenceType?
final
discountAccountRef → ReferenceType?
final
discountPercent → double?
final
hashCode → int
The hash code for this object.
no setterinherited
percentBased → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxCodeRef → ReferenceType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited