ECheck class

Send and receive payments using EChecks. Applicable for US only

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

ECheck({String? id, String? created, String? amount, String? description, PaymentContext? context, String? token, String? authCode, ECheckStatus? status, BankAccount? bankAccount, String? bankAccountOnFile, String? checkNumber, String? paymentMode})
ECheck.fromJson(Map<String, dynamic> json)
factory

Properties

amount → String?
final
authCode → String?
final
bankAccount → BankAccount?
final
bankAccountOnFile → String?
final
checkNumber → String?
final
context → PaymentContext?
final
created → String?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
paymentMode → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ECheckStatus?
final
token → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited