Employee class

An Employee object represents a person working for the company. If you are looking to create a Contractor via API, refer how to create a Vendor object, with Vendor1099 field set to true.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Employee({String? title, String? suffix, String? printOnCheckName, EmailAddress? primaryEmailAddr, TelephoneNumber? mobile, String? middleName, String? givenName, String? familyName, String? displayName, bool? active, ModificationMetaData? metaData, String? syncToken, TelephoneNumber? primaryPhone, String? id, bool? billableTime, double? billRate, String? birthDate, double? costRate, String? employeeNumber, String? gender, String? hiredDate, bool? organization, PhysicalAddress? primaryAddr, String? releasedDate, String? ssn, String? v4IDPseudonym})
Employee.fromJson(Map<String, dynamic> json)
factory

Properties

active → bool?
final
billableTime → bool?
final
billRate → double?
final
birthDate → String?
final
costRate → double?
final
displayName → String?
final
employeeNumber → String?
final
familyName → String?
final
gender → String?
final
givenName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
hiredDate → String?
final
id → String?
final
metaData → ModificationMetaData?
final
middleName → String?
final
mobile → TelephoneNumber?
final
organization → bool?
final
primaryAddr → PhysicalAddress?
final
primaryEmailAddr → EmailAddress?
final
primaryPhone → TelephoneNumber?
final
printOnCheckName → String?
final
releasedDate → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ssn → String?
final
suffix → String?
final
syncToken → String?
final
title → String?
final
v4IDPseudonym → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited