Estimate class

he Estimate represents a proposal for a financial transaction from a business to a customer for goods or services proposed to be sold, including proposed pricing.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Estimate({String? id, String? syncToken, ModificationMetaData? metaData, PhysicalAddress? shipAddr, PhysicalAddress? billAddr, CurrencyRefType? currencyRef, ReferenceType? salesTermRef, List<Line>? line, ReferenceType? classRef, ReferenceType? customerRef, TxnTaxDetail? txnTaxDetail, String? transactionLocationType, double? totalAmt, String? privateNote, GlobalTaxCalculationEnum? globalTaxCalculation, double? exchangeRate, Date? dueDate, String? docNumber, ReferenceType? departmentRef, List<LinkedTxn>? linkedTxn, String? txnDate, String? acceptedBy, Date? acceptedDate, bool? applyTaxAfterDiscount, EmailAddress? billEmail, MemoRef? customerMemo, List<CustomField>? customField, String? emailStatus, Date? expirationDate, bool? freeFormAddress, double? homeTotalAmt, String? printStatus, ReferenceType? recurDataRef, Date? shipDate, PhysicalAddress? shipFromAddr, ReferenceType? shipMethodRef, ReferenceType? taxExemptionRef, String? txnStatus})
Estimate.fromJson(Map<String, dynamic> json)
factory

Properties

acceptedBy → String?
final
acceptedDate → Date?
final
applyTaxAfterDiscount → bool?
final
billAddr → PhysicalAddress?
final
billEmail → EmailAddress?
final
classRef → ReferenceType?
final
currencyRef → CurrencyRefType?
final
customerMemo → MemoRef?
final
customerRef → ReferenceType?
final
customField → List<CustomField>?
final
departmentRef → ReferenceType?
final
docNumber → String?
final
dueDate → Date?
final
emailStatus → String?
final
exchangeRate → double?
final
expirationDate → Date?
final
freeFormAddress → bool?
final
globalTaxCalculation → GlobalTaxCalculationEnum?
final
hashCode → int
The hash code for this object.
no setterinherited
homeTotalAmt → double?
final
id → String?
final
line → List<Line>?
final
linkedTxn → List<LinkedTxn>?
final
metaData → ModificationMetaData?
final
printStatus → String?
final
privateNote → String?
final
recurDataRef → ReferenceType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salesTermRef → ReferenceType?
final
shipAddr → PhysicalAddress?
final
shipDate → Date?
final
shipFromAddr → PhysicalAddress?
final
shipMethodRef → ReferenceType?
final
syncToken → String?
final
taxExemptionRef → ReferenceType?
final
totalAmt → double?
final
transactionLocationType → String?
final
txnDate → String?
final
txnStatus → String?
final
txnTaxDetail → TxnTaxDetail?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited