Invoice class

An Invoice represents a sales form where the customer pays for a product or service later.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Invoice({String? id, ReferenceType? classRef, ReferenceType? shipMethodRef, PhysicalAddress? shipFromAddr, String? shipDate, ReferenceType? recurDataRef, String? printStatus, double? homeTotalAmt, bool? freeFormAddress, String? emailStatus, List<CustomField>? customField, MemoRef? customerMemo, EmailAddress? billEmail, bool? applyTaxAfterDiscount, String? txnDate, List<LinkedTxn>? linkedTxn, ReferenceType? departmentRef, String? docNumber, String? dueDate, double? exchangeRate, GlobalTaxCalculationEnum? globalTaxCalculation, String? privateNote, double? totalAmt, String? transactionLocationType, TxnTaxDetail? txnTaxDetail, ReferenceType? customerRef, List<Line>? line, ReferenceType? salesTermRef, CurrencyRefType? currencyRef, PhysicalAddress? shipAddr, ModificationMetaData? metaData, String? syncToken, double? balance, double? homeBalance, bool? allowIPNPayment, bool? allowOnlineACHPayment, bool? allowOnlineCreditCardPayment, bool? allowOnlinePayment, PhysicalAddress? billAddr, EmailAddress? billEmailBcc, EmailAddress? billEmailCc, DeliveryInfo? deliveryInfo, double? deposit, ReferenceType? depositToAccountRef, String? invoiceLink, ReferenceType? taxExemptionRef, String? trackingNum, String? txnSource})
Invoice.fromJson(Map<String, dynamic> json)
factory

Properties

allowIPNPayment → bool?
final
allowOnlineACHPayment → bool?
final
allowOnlineCreditCardPayment → bool?
final
allowOnlinePayment → bool?
final
applyTaxAfterDiscount → bool?
final
balance → double?
final
billAddr → PhysicalAddress?
final
billEmail → EmailAddress?
final
billEmailBcc → EmailAddress?
final
billEmailCc → EmailAddress?
final
classRef → ReferenceType?
final
currencyRef → CurrencyRefType?
final
customerMemo → MemoRef?
final
customerRef → ReferenceType?
final
customField → List<CustomField>?
final
deliveryInfo → DeliveryInfo?
final
departmentRef → ReferenceType?
final
deposit → double?
final
depositToAccountRef → ReferenceType?
final
docNumber → String?
final
dueDate → String?
final
emailStatus → String?
final
exchangeRate → double?
final
freeFormAddress → bool?
final
globalTaxCalculation → GlobalTaxCalculationEnum?
final
hashCode → int
The hash code for this object.
no setterinherited
homeBalance → double?
final
homeTotalAmt → double?
final
id → String?
final
final
line → List<Line>?
final
linkedTxn → List<LinkedTxn>?
final
metaData → ModificationMetaData?
final
printStatus → String?
final
privateNote → String?
final
recurDataRef → ReferenceType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salesTermRef → ReferenceType?
final
shipAddr → PhysicalAddress?
final
shipDate → String?
final
shipFromAddr → PhysicalAddress?
final
shipMethodRef → ReferenceType?
final
syncToken → String?
final
taxExemptionRef → ReferenceType?
final
totalAmt → double?
final
trackingNum → String?
final
transactionLocationType → String?
final
txnDate → String?
final
txnSource → String?
final
txnTaxDetail → TxnTaxDetail?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited