Item class

An item is a thing that your company buys, sells, or re-sells, such as products and services. An item is shown as a line on an invoice or other sales form.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Item({String? syncToken, ModificationMetaData? metaData, ReferenceType? classRef, String? id, String? description, ReferenceType? taxClassificationRef, double? unitPrice, String? type, String? name, bool? active, bool? taxable, String? source, int? level, ReferenceType? parentRef, String? fullyQualifiedName, double? abatementRate, ReferenceType? assetAccountRef, ReferenceType? expenseAccountRef, ReferenceType? incomeAccountRef, String? invStartDate, String? itemCategoryType, ReferenceType? prefVendorRef, double? purchaseCost, String? purchaseDesc, ReferenceType? purchaseTaxCodeRef, bool? purchaseTaxIncluded, double? qtyOnHand, double? reorderPoint, double? reverseChargeRate, ReferenceType? salesTaxCodeRef, bool? salesTaxIncluded, String? serviceType, String? sku, bool? subItem, bool? trackQtyOnHand, String? uQCDisplayText, String? uQCId})
Item.fromJson(Map<String, dynamic> json)
factory

Properties

abatementRate → double?
final
active → bool?
final
assetAccountRef → ReferenceType?
final
classRef → ReferenceType?
final
description → String?
final
expenseAccountRef → ReferenceType?
final
fullyQualifiedName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
incomeAccountRef → ReferenceType?
final
invStartDate → String?
final
itemCategoryType → String?
final
level → int?
final
metaData → ModificationMetaData?
final
name → String?
final
parentRef → ReferenceType?
final
prefVendorRef → ReferenceType?
final
purchaseCost → double?
final
purchaseDesc → String?
final
purchaseTaxCodeRef → ReferenceType?
final
purchaseTaxIncluded → bool?
final
qtyOnHand → double?
final
reorderPoint → double?
final
reverseChargeRate → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salesTaxCodeRef → ReferenceType?
final
salesTaxIncluded → bool?
final
serviceType → String?
final
sku → String?
final
source → String?
final
subItem → bool?
final
syncToken → String?
final
taxable → bool?
final
taxClassificationRef → ReferenceType?
final
trackQtyOnHand → bool?
final
type → String?
final
unitPrice → double?
final
uQCDisplayText → String?
final
uQCId → String?
final

Methods

copyWith({String? id, String? itemCategoryType, String? name, String? syncToken, String? invStartDate, String? type, double? qtyOnHand, ReferenceType? assetAccountRef, String? sku, bool? salesTaxIncluded, bool? trackQtyOnHand, ReferenceType? salesTaxCodeRef, ReferenceType? classRef, String? source, bool? purchaseTaxIncluded, String? description, double? abatementRate, bool? subItem, bool? taxable, String? uQCDisplayText, double? reorderPoint, String? purchaseDesc, ModificationMetaData? metaData, ReferenceType? prefVendorRef, bool? active, String? uQCId, double? reverseChargeRate, ReferenceType? purchaseTaxCodeRef, String? serviceType, double? purchaseCost, ReferenceType? parentRef, double? unitPrice, String? fullyQualifiedName, ReferenceType? expenseAccountRef, int? level, ReferenceType? incomeAccountRef, ReferenceType? taxClassificationRef}) → Item
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited