ItemBasedExpenseLineDetail class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

ItemBasedExpenseLineDetail({ReferenceType? taxCodeRef, BillableStatusEnum? billableStatus, ReferenceType? classRef, ReferenceType? customerRef, ReferenceType? itemRef, MarkupInfo? markupInfo, ReferenceType? priceLevelRef, double? qty, double? taxInclusiveAmt, double? unitPrice})
ItemBasedExpenseLineDetail.fromJson(Map<String, dynamic> json)
factory

Properties

billableStatus → BillableStatusEnum?
final
classRef → ReferenceType?
final
customerRef → ReferenceType?
final
hashCode → int
The hash code for this object.
no setterinherited
itemRef → ReferenceType?
final
markupInfo → MarkupInfo?
final
priceLevelRef → ReferenceType?
final
qty → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxCodeRef → ReferenceType?
final
taxInclusiveAmt → double?
final
unitPrice → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited