Payment class

A Payment object records a payment in QuickBooks. The payment can be applied for a particular customer against multiple Invoices and Credit Memos. It can also be created without any Invoice or Credit Memo, by just specifying an amount.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Payment({String? id, ModificationMetaData? metaData, String? syncToken, String? txnSource, ReferenceType? depositToAccountRef, ReferenceType? customerRef, String? transactionLocationType, double? totalAmt, String? privateNote, double? exchangeRate, String? txnDate, CurrencyRefType? currencyRef, ReferenceType? taxExemptionRef, ReferenceType? paymentMethodRef, ReferenceType? aRAccountRef, CreditCardPayment? creditCardPayment, String? paymentRefNum, double? unappliedAmt})
Payment.fromJson(Map<String, dynamic> json)
factory

Properties

aRAccountRef → ReferenceType?
final
creditCardPayment → CreditCardPayment?
final
currencyRef → CurrencyRefType?
final
customerRef → ReferenceType?
final
depositToAccountRef → ReferenceType?
final
exchangeRate → double?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
metaData → ModificationMetaData?
final
paymentMethodRef → ReferenceType?
final
paymentRefNum → String?
final
privateNote → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syncToken → String?
final
taxExemptionRef → ReferenceType?
final
totalAmt → double?
final
transactionLocationType → String?
final
txnDate → String?
final
txnSource → String?
final
unappliedAmt → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited