PaymentContext class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

PaymentContext({bool? mobile, DeviceInfo? deviceInfo, bool? isEcommerce, Lodging? lodging, bool? recurring, Restaurant? restaurant, String? tax})
PaymentContext.fromJson(Map<String, dynamic> json)
factory

Properties

deviceInfo → DeviceInfo?
final
hashCode → int
The hash code for this object.
no setterinherited
isEcommerce → bool?
final
lodging → Lodging?
final
mobile → bool?
final
recurring → bool?
final
restaurant → Restaurant?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tax → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited