PhysicalAddress class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

PhysicalAddress({String? country, String? id, String? city, String? countrySubDivisionCode, String? lat, String? line1, String? line2, String? line3, String? line4, String? line5, String? long, String? postalCode})
PhysicalAddress.fromJson(Map<String, dynamic> json)
factory

Properties

city → String?
final
country → String?
final
countrySubDivisionCode → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
lat → String?
final
line1 → String?
final
line2 → String?
final
line3 → String?
final
line4 → String?
final
line5 → String?
final
long → String?
final
postalCode → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited