Preferences class

The Preferences resource represents a set of company preferences that control application behavior in QuickBooks Online. They are mostly exposed as read-only through the Preferences endpoint with only a very small subset of them available as writable. Preferences are not necessarily honored when making requests via the QuickBooks API because a lot of them control UI behavior in the application and may not be applicable for apps.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Preferences({String? syncToken, ModificationMetaData? metaData, String? id, AccountingInfoPrefs? accountingInfoPrefs, CurrencyPrefs? currencyPrefs, EmailMessagesPrefs? emailMessagesPrefs, OtherPrefs? otherPrefs, ProductAndServicesPrefs? productAndServicesPrefs, ReportPrefs? reportPrefs, SalesFormsPrefs? salesFormsPrefs, TaxPrefs? taxPrefs, TimeTrackingPrefs? timeTrackingPrefs, VendorAndPurchasesPrefs? vendorAndPurchasesPrefs})
Preferences.fromJson(Map<String, dynamic> json)
factory

Properties

accountingInfoPrefs → AccountingInfoPrefs?
final
currencyPrefs → CurrencyPrefs?
final
emailMessagesPrefs → EmailMessagesPrefs?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
metaData → ModificationMetaData?
final
otherPrefs → OtherPrefs?
final
productAndServicesPrefs → ProductAndServicesPrefs?
final
reportPrefs → ReportPrefs?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salesFormsPrefs → SalesFormsPrefs?
final
syncToken → String?
final
taxPrefs → TaxPrefs?
final
timeTrackingPrefs → TimeTrackingPrefs?
final
vendorAndPurchasesPrefs → VendorAndPurchasesPrefs?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited