ProductAndServicesPrefs class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

ProductAndServicesPrefs({bool? forPurchase, bool? forSales, bool? quantityOnHand, bool? quantityWithPriceAndRate})
ProductAndServicesPrefs.fromJson(Map<String, dynamic> json)
factory

Properties

forPurchase → bool?
final
forSales → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
quantityOnHand → bool?
final
quantityWithPriceAndRate → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited