ProfitAndLoss class

The information below provides a reference on how to access the Profit and Loss Summary report from the QuickBooks Online Report Service.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

ProfitAndLoss({ProfitColumns? columns, ProfitHeader? header, ProfitRows? rows})
ProfitAndLoss.fromJson(Map<String, dynamic> json)
factory

Properties

columns → ProfitColumns?
final
hashCode → int
The hash code for this object.
no setterinherited
final
rows → ProfitRows?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited