ProfitAndLossQuery class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

ProfitAndLossQuery({String? customer, String? vendor, String? item, String? department, String? accounting_method, String? adjusted_gain_loss, String? date_macro, String? end_date, String? qzurl, String? reportClass, String? sort_order, String? start_date, String? summarize_column_by})
ProfitAndLossQuery.fromJson(Map<String, dynamic> json)
factory

Properties

accounting_method → String?
final
adjusted_gain_loss → String?
final
customer → String?
final
date_macro → String?
final
department → String?
final
end_date → String?
final
hashCode → int
The hash code for this object.
no setterinherited
item → String?
final
qzurl → String?
final
reportClass → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sort_order → String?
final
start_date → String?
final
summarize_column_by → String?
final
vendor → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited