ProfitHeader class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

ProfitHeader({String? className, String? currency, String? customer, String? department, String? employee, String? endPeriod, String? item, List<Option>? options, String? reportBasis, String? reportName, String? startPeriod, String? summarizeColumnsBy, String? time, String? vendor})
ProfitHeader.fromJson(Map<String, dynamic> json)
factory

Properties

className → String?
final
currency → String?
final
customer → String?
final
department → String?
final
employee → String?
final
endPeriod → String?
final
hashCode → int
The hash code for this object.
no setterinherited
item → String?
final
options → List<Option>?
final
reportBasis → String?
final
reportName → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startPeriod → String?
final
summarizeColumnsBy → String?
final
time → String?
final
vendor → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited