Restaurant class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Restaurant({double? taxAmount, double? beverageAmount, double? foodAmount, String? serverID, double? tipAmount})
Restaurant.fromJson(Map<String, dynamic> json)
factory

Properties

beverageAmount → double?
final
foodAmount → double?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverID → String?
final
taxAmount → double?
final
tipAmount → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited