SalesFormsPrefs class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

SalesFormsPrefs({String? estimateMessage, List<CustomField>? customFields, bool? allowDeposit, bool? allowDiscount, bool? allowEstimates, bool? allowServiceDate, bool? allowShipping, bool? autoApplyCredit, bool? customTxnNumbers, String? defaultCustomerMessage, String? defaultDiscountAccount, bool? defaultShippingAccount, ReferenceType? defaultTerms, bool? emailCopyToCompany, bool? eTransactionAttachPDF, String? eTransactionEnabledStatus, bool? eTransactionPaymentEnabled, bool? iPNSupportEnabled, EmailAddress? salesEmailBcc, EmailAddress? salesEmailCc, bool? usingPriceLevels, bool? usingProgressInvoicing})
SalesFormsPrefs.fromJson(Map<String, dynamic> json)
factory

Properties

allowDeposit → bool?
final
allowDiscount → bool?
final
allowEstimates → bool?
final
allowServiceDate → bool?
final
allowShipping → bool?
final
autoApplyCredit → bool?
final
customFields → List<CustomField>?
final
customTxnNumbers → bool?
final
defaultCustomerMessage → String?
final
defaultDiscountAccount → String?
final
defaultShippingAccount → bool?
final
defaultTerms → ReferenceType?
final
emailCopyToCompany → bool?
final
estimateMessage → String?
final
eTransactionAttachPDF → bool?
final
eTransactionEnabledStatus → String?
final
eTransactionPaymentEnabled → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
iPNSupportEnabled → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salesEmailBcc → EmailAddress?
final
salesEmailCc → EmailAddress?
final
usingPriceLevels → bool?
final
usingProgressInvoicing → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited