SalesItemLineDetail class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

SalesItemLineDetail({ReferenceType? classRef, ReferenceType? taxCodeRef, MarkupInfo? markupInfo, double? taxInclusiveAmt, double? unitPrice, double? qty, ReferenceType? itemRef, double? discountAmt, double? discountRate, ReferenceType? itemAccountRef, String? serviceDate, ReferenceType? taxClassificationRef})
SalesItemLineDetail.fromJson(Map<String, dynamic> json)
factory

Properties

classRef → ReferenceType?
final
discountAmt → double?
final
discountRate → double?
final
hashCode → int
The hash code for this object.
no setterinherited
itemAccountRef → ReferenceType?
final
itemRef → ReferenceType?
final
markupInfo → MarkupInfo?
final
qty → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceDate → String?
final
taxClassificationRef → ReferenceType?
final
taxCodeRef → ReferenceType?
final
taxInclusiveAmt → double?
final
unitPrice → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited