Scope class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

Accounting → Scope
final
Address → Scope
final
Email → Scope
final
Invalid → Scope
final
OpenId → Scope
final
Payments → Scope
final
Phone → Scope
final
Profile → Scope
final

Static Methods

findById(String id) → Scope