TaxAgency class

A TaxAgency object is associated with a tax rate and identifies the agency to which that tax rate applies, that is, the entity that collects those taxes.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

TaxAgency({String? id, ModificationMetaData? metaData, String? syncToken, String? displayName, String? lastFileDate, String? taxAgencyConfig, String? taxRegistrationNumber, bool? taxTrackedOnPurchases, bool? taxTrackedOnSales})
TaxAgency.fromJson(Map<String, dynamic> json)
factory

Properties

displayName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
lastFileDate → String?
final
metaData → ModificationMetaData?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syncToken → String?
final
taxAgencyConfig → String?
final
taxRegistrationNumber → String?
final
taxTrackedOnPurchases → bool?
final
taxTrackedOnSales → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited