TaxLineDetail class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

TaxLineDetail({double? netAmountTaxable, double? overrideDeltaAmount, bool? percentBased, double? taxInclusiveAmount, double? taxPercent, required ReferenceType taxRateRef})
TaxLineDetail.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
netAmountTaxable → double?
final
overrideDeltaAmount → double?
final
percentBased → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxInclusiveAmount → double?
final
taxPercent → double?
final
taxRateRef → ReferenceType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited