TimeTrackingPrefs class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

TimeTrackingPrefs({bool? usingSalesTax, bool? billCustomers, bool? markTimeEntriesBillable, bool? showBillRateToAll, String? workWeekStartDate})
TimeTrackingPrefs.fromJson(Map<String, dynamic> json)
factory

Properties

billCustomers → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
markTimeEntriesBillable → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showBillRateToAll → bool?
final
usingSalesTax → bool?
final
workWeekStartDate → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited