TokenResponse class

Response from oAth tokens.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

TokenResponse({String? refresh_token, String? access_token, int? expires_in, String? idToken, int? x_refresh_token_expires_in})
TokenResponse.fromJson(Map<String, dynamic> json)
factory

Properties

access_token → String?
final
expires_in → int?
final
hashCode → int
The hash code for this object.
no setterinherited
idToken → String?
final
refresh_token → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x_refresh_token_expires_in → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited