Vendor class

The Vendor object represents the seller from whom your company purchases any service or product.

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Vendor({String? displayName, String? syncToken, ModificationMetaData? metaData, String? id, String? source, bool? active, double? balance, CurrencyRefType? currencyRef, PhysicalAddress? billAddr, double? costRate, double? billRate, TelephoneNumber? primaryPhone, String? familyName, String? givenName, String? middleName, TelephoneNumber? mobile, EmailAddress? primaryEmailAddr, String? printOnCheckName, String? suffix, String? title, String? gSTRegistrationType, String? gSTIN, TelephoneNumber? fax, String? businessNumber, TelephoneNumber? alternatePhone, String? companyName, WebSiteAddress? webAddr, ReferenceType? aPAccountRef, String? acctNum, bool? hasTPAR, ContactInfo? otherContactInfo, bool? t4AEligible, bool? t5018Eligible, String? taxIdentifier, String? taxReportingBasis, ReferenceType? termRef, bool? vendor1099, VendorPaymentBankDetail? vendorPaymentBankDetail})
Vendor.fromJson(Map<String, dynamic> json)
factory

Properties

acctNum → String?
final
active → bool?
final
alternatePhone → TelephoneNumber?
final
aPAccountRef → ReferenceType?
final
balance → double?
final
billAddr → PhysicalAddress?
final
billRate → double?
final
businessNumber → String?
final
companyName → String?
final
costRate → double?
final
currencyRef → CurrencyRefType?
final
displayName → String?
final
familyName → String?
final
fax → TelephoneNumber?
final
givenName → String?
final
gSTIN → String?
final
gSTRegistrationType → String?
final
hashCode → int
The hash code for this object.
no setterinherited
hasTPAR → bool?
final
id → String?
final
metaData → ModificationMetaData?
final
middleName → String?
final
mobile → TelephoneNumber?
final
otherContactInfo → ContactInfo?
final
primaryEmailAddr → EmailAddress?
final
primaryPhone → TelephoneNumber?
final
printOnCheckName → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
final
suffix → String?
final
syncToken → String?
final
t4AEligible → bool?
final
t5018Eligible → bool?
final
taxIdentifier → String?
final
taxReportingBasis → String?
final
termRef → ReferenceType?
final
title → String?
final
vendor1099 → bool?
final
vendorPaymentBankDetail → VendorPaymentBankDetail?
final
webAddr → WebSiteAddress?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited